@@ -1,6 +1,6 @@
 /* EEG.cpp
  *
- * Copyright (C) 2011-2012,2013,2014,2015,2017 Paul Boersma
+ * Copyright (C) 2011-2018 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -571,6 +571,68 @@ autoEEG EEG_extractChannel (EEG me, const char32 *channelName) {
 	}
 }
 
+autoEEG EEG_extractChannels (EEG me, numvec channelNumbers) {
+	try {
+		integer numberOfChannels = channelNumbers.size;
+		Melder_require (numberOfChannels > 0,
+			U"The number of channels should be greater than 0.");
+		autoEEG you = EEG_create (my xmin, my xmax);
+		your sound = Sound_extractChannels (my sound.get(), channelNumbers);
+		your numberOfChannels = numberOfChannels;
+		your channelNames = NUMvector <char32 *> (1, numberOfChannels);
+		for (integer ichan = 1; ichan <= numberOfChannels; ichan ++) {
+			integer originalChannelNumber = Melder_iround (channelNumbers [ichan]);
+			your channelNames [ichan] = Melder_dup (my channelNames [originalChannelNumber]);
+		}
+		your textgrid = Data_copy (my textgrid.get());
+		return you;
+	} catch (MelderError) {
+		Melder_throw (me, U": channels not extracted.");
+	}
+}
+
+static void Sound_removeChannel (Sound me, integer channelNumber) {
+	try {
+		Melder_require (channelNumber >= 1 && channelNumber <= my ny,
+			U"No channel ", channelNumber, U".");
+		Melder_require (my ny > 1,
+			U"Cannot remove last remaining channel.");
+		for (integer ichan = channelNumber; ichan < my ny; ichan ++) {
+			NUMvector_copyElements (my z [ichan + 1], my z [ichan], 1, my nx);
+		}
+		my ymax -= 1.0;
+		my ny -= 1;
+	} catch (MelderError) {
+		Melder_throw (me, U": channel ", channelNumber, U" not removed.");
+	}
+}
+
+void EEG_removeChannel (EEG me, integer channelNumber) {
+	try {
+		if (channelNumber < 1 || channelNumber > my numberOfChannels)
+			Melder_throw (U"No channel ", channelNumber, U".");
+		Melder_free (my channelNames [channelNumber]);
+		for (integer ichan = channelNumber; ichan < my numberOfChannels; ichan ++) {
+			my channelNames [ichan] = my channelNames [ichan + 1];
+		}
+		my numberOfChannels -= 1;
+		Sound_removeChannel (my sound.get(), channelNumber);
+	} catch (MelderError) {
+		Melder_throw (me, U": channel ", channelNumber, U" not removed.");
+	}
+}
+
+void EEG_removeChannel (EEG me, const char32 *channelName) {
+	try {
+		integer channelNumber = EEG_getChannelNumber (me, channelName);
+		if (channelNumber == 0)
+			Melder_throw (U"No channel named \"", channelName, U"\".");
+		EEG_removeChannel (me, channelNumber);
+	} catch (MelderError) {
+		Melder_throw (me, U": channel ", channelName, U" not removed.");
+	}
+}
+
 autoEEG EEGs_concatenate (OrderedOf<structEEG>* me) {
 	try {
 		if (my size < 1)
@@ -636,11 +698,14 @@ void EEG_replaceTextGrid (EEG me, TextGrid textgrid) {
 	}
 }
 
-autoMixingMatrix EEG_to_MixingMatrix (EEG me, integer maxNumberOfIterations, double tol, int method) {
+autoMixingMatrix EEG_to_MixingMatrix (EEG me,
+	double startTime, double endTime, integer numberOfCrossCorrelations, double lagStep,
+	integer maxNumberOfIterations, double tol, int method)
+{
 	try {
-		autoCrossCorrelationTableList tables = Sound_to_CrossCorrelationTableList (my sound.get(), 0.0, 0.0, 0.002, 1);
+		autoCrossCorrelationTableList tables = Sound_to_CrossCorrelationTableList (my sound.get(), startTime, endTime, numberOfCrossCorrelations, lagStep);
 		autoMixingMatrix thee = MixingMatrix_create (my sound -> ny, my sound -> ny);
-		MixingMatrix_setRandomGauss ( thee.get(), 0.0, 1.0);
+		MixingMatrix_setRandomGauss (thee.get(), 0.0, 1.0);
 		for (integer ichan = 1; ichan <= my numberOfChannels; ichan ++) {
 			TableOfReal_setRowLabel (thee.get(), ichan, my channelNames [ichan]);
 			TableOfReal_setColumnLabel (thee.get(), ichan, Melder_cat (U"ic", ichan));
@@ -652,4 +717,48 @@ autoMixingMatrix EEG_to_MixingMatrix (EEG me, integer maxNumberOfIterations, dou
 	}
 }
 
+autoEEG EEG_MixingMatrix_to_EEG_unmix (EEG me, MixingMatrix you) {
+	Melder_require (my numberOfChannels == your numberOfRows,
+		U"To be able to unmix, the number of channels in ", me, U" (", my numberOfChannels, U")",
+		U" should be equal to the number of rows in ", you, U" (", your numberOfRows, U").");
+	for (integer ichan = 1; ichan <= your numberOfRows; ichan ++) {
+		Melder_require (Melder_equ (my channelNames [ichan], your rowLabels [ichan]),
+			U"To be able to unmix, the name of channel ", ichan,
+			U" should be the same in ", me, U" (where it is ", my channelNames [ichan], U")",
+			U" as in ", you, U" (where it is ", your rowLabels [ichan], U").");
+	}
+	autoEEG him = EEG_create (my xmin, my xmax);
+	his sound = Sound_MixingMatrix_unmix (my sound.get(), you);
+	his textgrid = Data_copy (my textgrid.get());
+	his numberOfChannels = your numberOfColumns;
+	his channelNames = NUMvector <char32 *> (1, his numberOfChannels);
+	//his channelNames = NUMstrings_copy (your columnLabels, 1, his numberOfChannels);
+	for (integer ichan = 1; ichan <= his numberOfChannels; ichan ++) {
+		his channelNames [ichan] = Melder_dup (your columnLabels [ichan]);
+	}
+	return him;
+}
+
+autoEEG EEG_MixingMatrix_to_EEG_mix (EEG me, MixingMatrix you) {
+	Melder_require (my numberOfChannels == your numberOfColumns,
+		U"To be able to mix, the number of channels in ", me, U" (", my numberOfChannels, U")",
+		U" should be equal to the number of columns in ", you, U" (", your numberOfColumns, U").");
+	for (integer ichan = 1; ichan <= your numberOfColumns; ichan ++) {
+		Melder_require (Melder_equ (my channelNames [ichan], your columnLabels [ichan]),
+			U"To be able to mix, the name of channel ", ichan,
+			U" should be the same in ", me, U" (where it is ", my channelNames [ichan], U")",
+			U" as in ", you, U" (where it is ", your columnLabels [ichan], U").");
+	}
+	autoEEG him = EEG_create (my xmin, my xmax);
+	his sound = Sound_MixingMatrix_mix (my sound.get(), you);
+	his textgrid = Data_copy (my textgrid.get());
+	his numberOfChannels = your numberOfRows;
+	his channelNames = NUMvector <char32 *> (1, his numberOfChannels);
+	//his channelNames = NUMstrings_copy (your rowLabels, 1, his numberOfChannels);
+	for (integer ichan = 1; ichan <= his numberOfChannels; ichan ++) {
+		his channelNames [ichan] = Melder_dup (your rowLabels [ichan]);
+	}
+	return him;
+}
+
 /* End of file EEG.cpp */
