@@ -202,7 +202,7 @@ void ERP_drawScalp (ERP me, Graphics graphics, double tmin, double tmax, double
 			double x = -1.0 + (icol - 1) * d;
 			if (x * x + y * y <= 1.0) {
 				double value = undefined;
-				real80 sum = 0.0, weight = 0.0;
+				longdouble sum = 0.0, weight = 0.0;
 				for (integer ichan = 1; ichan <= numberOfDrawableChannels; ichan ++) {
 					double dx = x - biosemiLocationData [ichan]. topX;
 					double dy = y - biosemiLocationData [ichan]. topY;
@@ -216,7 +216,7 @@ void ERP_drawScalp (ERP me, Graphics graphics, double tmin, double tmax, double
 					weight += 1.0 / distance;
 				}
 				if (isundef (value))
-					value = ( sum == 0.0 ? 0.0 : real (sum / weight) );
+					value = ( sum == 0.0 ? 0.0 : double (sum / weight) );
 				image [irow] [icol] = value;
 			}
 		}
@@ -306,7 +306,7 @@ void structERPWindow :: v_drawSelectionViewer () {
 			double x = -1.0 + (icol - 1) * d;
 			if (x * x + y * y <= 1.0) {
 				double value = undefined;
-				real80 sum = 0.0, weight = 0.0;
+				longdouble sum = 0.0, weight = 0.0;
 				for (integer ichan = 1; ichan <= numberOfDrawableChannels; ichan ++) {
 					double dx = x - biosemiLocationData [ichan]. topX;
 					double dy = y - biosemiLocationData [ichan]. topY;
@@ -320,7 +320,7 @@ void structERPWindow :: v_drawSelectionViewer () {
 					weight += 1.0 / distance;
 				}
 				if (isundef (value))
-					value = ( sum == 0.0 ? 0.0 : real (sum / weight) );
+					value = ( sum == 0.0 ? 0.0 : double (sum / weight) );
 				image [irow] [icol] = value;
 			}
 		}
