@@ -1,6 +1,6 @@
 /* praat_EEG.cpp
  *
- * Copyright (C) 2011-2012,2013,2014,2015,2016,2017 Paul Boersma
+ * Copyright (C) 2011-2018 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -153,6 +153,15 @@ DO
 	MODIFY_EACH_END
 }
 
+FORM (MODIFY_EEG_removeChannel, U"Remove channel", nullptr) {
+	SENTENCE (channel, U"Channel", U"Iz")
+	OK
+DO
+	MODIFY_EACH (EEG)
+		EEG_removeChannel (me, channel);
+	MODIFY_EACH_END
+}
+
 FORM (MODIFY_EEG_subtractMeanChannel, U"Subtract mean channel", nullptr) {
 	LABEL (U"Range of reference channels:")
 	NATURAL (fromChannel, U"From channel", U"1")
@@ -198,6 +207,15 @@ DO
 	CONVERT_EACH_END (my name, U"_", channelName)
 }
 
+FORM (NEW_EEG_extractChannels, U"EEG: Extract channels", nullptr) {
+	NUMVEC (channels, U"Channel numbers:", U"to# (64)")
+	OK
+DO
+	CONVERT_EACH (EEG)
+		autoEEG result = EEG_extractChannels (me, channels);
+	CONVERT_EACH_END (my name, U"_ch")
+}
+
 FORM (NEW_EEG_extractPart, U"EEG: Extract part", nullptr) {
 	REAL (fromTime, U"left Time range (s)", U"0.0")
 	REAL (toTime, U"right Time range (s)", U"1.0")
@@ -281,6 +299,9 @@ DIRECT (NEW1_EEGs_concatenate) {
 }
 
 FORM (NEW_EEG_to_MixingMatrix, U"To MixingMatrix", nullptr) {
+	praat_TimeFunction_RANGE (startTime, endTime)
+	NATURAL (numberOfCrossCorrelations, U"Number of cross-correlations", U"40")
+	POSITIVE (lagStep, U"Lag step (s)", U"0.002")
 	NATURAL (maximumNumberOfIterations, U"Maximum number of iterations", U"100")
 	POSITIVE (tolerance, U"Tolerance", U"0.001")
 	OPTIONMENUx (diagonalizationMethod, U"Diagonalization method", 2, 1)
@@ -290,10 +311,23 @@ FORM (NEW_EEG_to_MixingMatrix, U"To MixingMatrix", nullptr) {
 DO
 	CONVERT_EACH (EEG)
 		autoMixingMatrix result = EEG_to_MixingMatrix (me,
+			startTime, endTime, numberOfCrossCorrelations, lagStep,
 			maximumNumberOfIterations, tolerance, diagonalizationMethod);
 	CONVERT_EACH_END (my name)
 }
 
+DIRECT (NEW_EEG_MixingMatrix_to_EEG_unmix) {
+	CONVERT_TWO (EEG, MixingMatrix)
+		autoEEG result = EEG_MixingMatrix_to_EEG_unmix (me, you);
+	CONVERT_TWO_END (my name, U"_", your name)
+}
+
+DIRECT (NEW_EEG_MixingMatrix_to_EEG_mix) {
+	CONVERT_TWO (EEG, MixingMatrix)
+		autoEEG result = EEG_MixingMatrix_to_EEG_mix (me, you);
+	CONVERT_TWO_END (my name, U"_", your name)
+}
+
 // MARK: - EEG & TextGrid
 
 DIRECT (MODIFY_EEG_TextGrid_replaceTextGrid) {
@@ -696,10 +730,8 @@ DO
 
 static autoDaata bdfFileRecognizer (integer nread, const char * /* header */, MelderFile file) {
 	const char32 *fileName = MelderFile_name (file);
-	bool isBdfFile = Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".bdf") ||
-	                 Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".BDF");
-	bool isEdfFile = Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".edf") ||
-	                 Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".EDF");
+	bool isBdfFile = Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".bdf", false);
+	bool isEdfFile = Melder_stringMatchesCriterion (fileName, kMelder_string::ENDS_WITH, U".edf", false);
 	if (nread < 512 || (! isBdfFile && ! isEdfFile)) return autoDaata ();
 	return EEG_readFromBdfFile (file);
 }
@@ -728,8 +760,10 @@ void praat_EEG_init () {
 		praat_addAction1 (classEEG, 0, U"Filter...", nullptr, 1, MODIFY_EEG_filter);
 		praat_addAction1 (classEEG, 0, U"Remove triggers...", nullptr, 1, MODIFY_EEG_removeTriggers);
 		praat_addAction1 (classEEG, 0, U"Set channel to zero...", nullptr, 1, MODIFY_EEG_setChannelToZero);
+		praat_addAction1 (classEEG, 0, U"Remove channel...", nullptr, 1, MODIFY_EEG_removeChannel);
 	praat_addAction1 (classEEG, 0, U"Analyse", nullptr, 0, nullptr);
 		praat_addAction1 (classEEG, 0, U"Extract channel...", nullptr, 0, NEW_EEG_extractChannel);
+		praat_addAction1 (classEEG, 0, U"Extract channels...", nullptr, 0, NEW_EEG_extractChannels);
 		praat_addAction1 (classEEG, 0, U"Extract part...", nullptr, 0, NEW_EEG_extractPart);
 		praat_addAction1 (classEEG, 0, U"To ERPTier -", nullptr, 0, nullptr);
 		praat_addAction1 (classEEG, 0, U"To ERPTier (bit)...", nullptr, 1, NEW_EEG_to_ERPTier_bit);
@@ -790,6 +824,8 @@ void praat_EEG_init () {
 		praat_addAction1 (classERPTier, 0, U"Extract ERP...", nullptr, 0, NEW_ERPTier_to_ERP);
 		praat_addAction1 (classERPTier, 0, U"To ERP (mean)", nullptr, 0, NEW_ERPTier_to_ERP_mean);
 
+	praat_addAction2 (classEEG, 1, classMixingMatrix, 1, U"To EEG (unmix)", nullptr, 0, NEW_EEG_MixingMatrix_to_EEG_unmix);
+	praat_addAction2 (classEEG, 1, classMixingMatrix, 1, U"To EEG (mix)", nullptr, 0, NEW_EEG_MixingMatrix_to_EEG_mix);
 	praat_addAction2 (classEEG, 1, classTextGrid, 1, U"Replace TextGrid", nullptr, 0, MODIFY_EEG_TextGrid_replaceTextGrid);
 	praat_addAction2 (classERPTier, 1, classTable, 1, U"Extract -", nullptr, 0, nullptr);
 	praat_addAction2 (classERPTier, 1, classTable, 1, U"Extract events where column (number)...", nullptr, 1, NEW1_ERPTier_Table_extractEventsWhereColumn_number);
