@@ -41,11 +41,11 @@ int NUMstring_containsPrintableCharacter (const char32 *s) {
 
 void NUMstring_chopWhiteSpaceAtExtremes_inplace (char32 *string) {
 	int64 start = 0;
-	while (Melder_isWhiteSpace (string [start])) {
+	while (Melder_isHorizontalOrVerticalSpace (string [start])) {
 		start ++;
 	}
 	int64 end = str32len (string);
-	while (end != start && Melder_isWhiteSpace (string [end - 1])) {
+	while (end != start && Melder_isHorizontalOrVerticalSpace (string [end - 1])) {
 		end --;
 	}
 	int64 n = end - start;
@@ -53,12 +53,12 @@ void NUMstring_chopWhiteSpaceAtExtremes_inplace (char32 *string) {
 	string [n] = 0;
 }
 
-real *NUMstring_to_numbers (const char32 *s, integer *p_numbers_found) {
+double *NUMstring_to_numbers (const char32 *s, integer *p_numbers_found) {
 	integer numbers_found = Melder_countTokens (s);
 	if (numbers_found < 1) {
 		Melder_throw (U"Empty string.");
 	}
-	autoNUMvector <real> numbers (1, numbers_found);
+	autoNUMvector <double> numbers (1, numbers_found);
 	integer inum = 1;
 	for (char32 *token = Melder_firstToken (s); token; token = Melder_nextToken (), inum ++) {
 		Interpreter_numericExpression (0, token, & numbers [inum]);
@@ -412,20 +412,20 @@ static integer *getElementsOfRanges (const char32 *ranges, integer maximumElemen
 	for (;;) {
 		while (*p == U' ' || *p == U'\t') p ++;
 		if (*p == U'\0') break;
-		if (isdigit ((int) *p)) {
+		if (Melder_isAsciiDecimalNumber (*p)) {
 			integer currentElement = Melder_atoi (p);
 			Melder_require (currentElement != 0, U"No such ", elementType, U": 0 (minimum is 1).");
 			Melder_require (currentElement <= maximumElement, U"No such ", elementType, U": ", currentElement, U" (maximum is ", maximumElement, U").");
 			
 			*numberOfElements += 1;
 			previousElement = currentElement;
-			do { p ++; } while (isdigit ((int) *p));
+			do { p ++; } while (Melder_isAsciiDecimalNumber (*p));
 		} else if (*p == ':') {
 			Melder_require (previousElement != 0, U"The range should not start with a colon.");
 			
 			do { p ++; } while (*p == U' ' || *p == U'\t');
 			Melder_require (*p != U'\0', U"The range should not end with a colon.");
-			Melder_require (isdigit ((int) *p), U"End of range should be a positive whole number.");
+			Melder_require (Melder_isAsciiDecimalNumber (*p), U"End of range should be a positive whole number.");
 			
 			integer currentElement = Melder_atoi (p);
 			Melder_require (currentElement != 0, U"No such ", elementType, U": 0 (minimum is 1).");
@@ -437,7 +437,7 @@ static integer *getElementsOfRanges (const char32 *ranges, integer maximumElemen
 				*numberOfElements += previousElement - currentElement;
 			}
 			previousElement = currentElement;
-			do { p ++; } while (isdigit ((int) *p));
+			do { p ++; } while (Melder_isAsciiDecimalNumber (*p));
 		} else {
 			Melder_throw (U"Start of range should be a positive whole number.");
 		}
@@ -460,11 +460,11 @@ static integer *getElementsOfRanges (const char32 *ranges, integer maximumElemen
 	for (;;) {
 		while (*p == U' ' || *p == U'\t') p ++;
 		if (*p == U'\0') break;
-		if (isdigit ((int) *p)) {
+		if (Melder_isAsciiDecimalNumber (*p)) {
 			integer currentElement = Melder_atoi (p);
 			elements [++ *numberOfElements] = currentElement;
 			previousElement = currentElement;
-			do { p ++; } while (isdigit ((int) *p));
+			do { p ++; } while (Melder_isAsciiDecimalNumber (*p));
 		} else if (*p == U':') {
 			do { p ++; } while (*p == U' ' || *p == U'\t');
 			integer currentElement = Melder_atoi (p);
@@ -478,7 +478,7 @@ static integer *getElementsOfRanges (const char32 *ranges, integer maximumElemen
 				}
 			}
 			previousElement = currentElement;
-			do { p ++; } while (isdigit ((int) *p));
+			do { p ++; } while (Melder_isAsciiDecimalNumber (*p));
 		}
 	}
 	return elements.transfer();
