@@ -25,19 +25,19 @@
 #include "DTW_and_TextGrid.h"
 
 // begin old prototypes for compatibility reasons with the past
-autoTextGrid DTW_and_TextGrid_to_TextGrid_old (DTW me, TextGrid thee);
-autoIntervalTier DTW_and_IntervalTier_to_IntervalTier_old (DTW me, IntervalTier thee);
-autoTextTier DTW_and_TextTier_to_TextTier_old (DTW me, TextTier thee);
+autoTextGrid DTW_TextGrid_to_TextGrid_old (DTW me, TextGrid thee);
+autoIntervalTier DTW_IntervalTier_to_IntervalTier_old (DTW me, IntervalTier thee);
+autoTextTier DTW_TextTier_to_TextTier_old (DTW me, TextTier thee);
 // end old
 
 /* Get times from TextGrid and substitute new time form the y-times of the DTW. */
-autoTextTier DTW_and_TextTier_to_TextTier (DTW me, TextTier thee, double precision) {
+autoTextTier DTW_TextTier_to_TextTier (DTW me, TextTier thee, double precision) {
 	try {
 		if (fabs (my ymin - thy xmin) <= precision && fabs (my ymax - thy xmax) <= precision) { // map from Y to X
 			autoTextTier him = Data_copy (thee);
 			his xmin = my xmin;
 			his xmax = my xmax;
-			for (long i = 1; i <= his points.size; i++) {
+			for (integer i = 1; i <= his points.size; i ++) {
 				TextPoint textpoint = his points.at [i];
 				double time = DTW_getXTimeFromYTime (me, textpoint -> number);
 				textpoint -> number = time;
@@ -47,27 +47,27 @@ autoTextTier DTW_and_TextTier_to_TextTier (DTW me, TextTier thee, double precisi
 			autoTextTier him = Data_copy (thee);
 			his xmin = my ymin;
 			his xmax = my ymax;
-			for (long i = 1; i <= his points.size; i++) {
+			for (integer i = 1; i <= his points.size; i ++) {
 				TextPoint textpoint = his points.at [i];
 				double time = DTW_getYTimeFromXTime (me, textpoint -> number);
 				textpoint -> number = time;
 			}
 			return him;
 		} else {
-			Melder_throw (U"The domain of the TextTier and one of the domains of the DTW must be equal.");
+			Melder_throw (U"The domain of the TextTier and one of the domains of the DTW should be equal.");
 		}
 	} catch (MelderError) {
 		Melder_throw (U"TextTier not created from DTW & TextTier.");
 	}
 }
 
-autoIntervalTier DTW_and_IntervalTier_to_IntervalTier (DTW me, IntervalTier thee, double precision) {
+autoIntervalTier DTW_IntervalTier_to_IntervalTier (DTW me, IntervalTier thee, double precision) {
 	try {
 		if (fabs (my ymin - thy xmin) <= precision && fabs (my ymax - thy xmax) <= precision) { // map from Y to X
 			autoIntervalTier him = Data_copy (thee);
 			his xmin = my xmin;
 			his xmax = my xmax;
-			for (long i = 1; i <= his intervals.size; i ++) {
+			for (integer i = 1; i <= his intervals.size; i ++) {
 				TextInterval textinterval = his intervals.at [i];
 				double xmin = DTW_getXTimeFromYTime (me, textinterval -> xmin);
 				textinterval -> xmin = xmin;
@@ -79,7 +79,7 @@ autoIntervalTier DTW_and_IntervalTier_to_IntervalTier (DTW me, IntervalTier thee
 			autoIntervalTier him = Data_copy (thee);
 			his xmin = my ymin;
 			his xmax = my ymax;
-			for (long i = 1; i <= his intervals.size; i ++) {
+			for (integer i = 1; i <= his intervals.size; i ++) {
 				TextInterval textinterval = his intervals.at [i];
 				double xmin = DTW_getYTimeFromXTime (me, textinterval -> xmin);
 				textinterval -> xmin = xmin;
@@ -88,14 +88,14 @@ autoIntervalTier DTW_and_IntervalTier_to_IntervalTier (DTW me, IntervalTier thee
 			}
 			return him;
 		} else {
-			Melder_throw (U"The domain of the IntervalTier and one of the domains of the DTW must be equal.");
+			Melder_throw (U"The domain of the IntervalTier and one of the domains of the DTW should be equal.");
 		}
 	} catch (MelderError) {
 		Melder_throw (U"IntervalTier not created from DTW & IntervalTier.");
 	}
 }
 
-autoTextGrid DTW_and_TextGrid_to_TextGrid (DTW me, TextGrid thee, double precision) {
+autoTextGrid DTW_TextGrid_to_TextGrid (DTW me, TextGrid thee, double precision) {
 	try {
 		double tmin, tmax;
 		if (fabs (my ymin - thy xmin) <= precision && fabs (my ymax - thy xmax) <= precision) {
@@ -105,19 +105,19 @@ autoTextGrid DTW_and_TextGrid_to_TextGrid (DTW me, TextGrid thee, double precisi
 			tmin = my ymin;
 			tmax = my ymax;
 		} else {
-			Melder_throw (U"The domain of the TextGrid must be equal to one of the domains of the DTW.");
+			Melder_throw (U"The domain of the TextGrid should be equal to one of the domains of the DTW.");
 		}
 
 		autoTextGrid him = TextGrid_createWithoutTiers (tmin, tmax);
 
-		for (long i = 1; i <= thy tiers->size; i ++) {
+		for (integer i = 1; i <= thy tiers->size; i ++) {
 			Function anyTier = thy tiers->at [i];
 
 			if (anyTier -> classInfo == classIntervalTier) {
-				autoIntervalTier tier = DTW_and_IntervalTier_to_IntervalTier (me, (IntervalTier) anyTier, precision);
+				autoIntervalTier tier = DTW_IntervalTier_to_IntervalTier (me, (IntervalTier) anyTier, precision);
 				TextGrid_addTier_copy (him.get(), tier.get());
 			} else if (anyTier -> classInfo == classTextTier) {
-				autoTextTier tier = DTW_and_TextTier_to_TextTier (me, (TextTier) anyTier, precision);
+				autoTextTier tier = DTW_TextTier_to_TextTier (me, (TextTier) anyTier, precision);
 				TextGrid_addTier_copy (him.get(), tier.get());
 			} else {
 				Melder_throw (U"Unknown tier.");
@@ -129,22 +129,22 @@ autoTextGrid DTW_and_TextGrid_to_TextGrid (DTW me, TextGrid thee, double precisi
 	}
 }
 
-autoTable DTW_and_IntervalTier_to_Table (DTW me, IntervalTier thee, double precision) {
+autoTable DTW_IntervalTier_to_Table (DTW me, IntervalTier thee, double precision) {
 	try {
-		long numberOfIntervals = thy intervals.size;
+		integer numberOfIntervals = thy intervals.size;
 		autoTable him = Table_createWithColumnNames (numberOfIntervals, U"tmin tmax label dist");
 		if (fabs (my ymin - thy xmin) <= precision && fabs (my ymax - thy xmax) <= precision) { // map from Y to X
-			long pathIndex = 1;
-			for (long i = 1; i <= numberOfIntervals; i ++) {
+			integer pathIndex = 1;
+			for (integer i = 1; i <= numberOfIntervals; i ++) {
 				TextInterval textinterval = thy intervals.at [i];
 				double xmin = DTW_getXTimeFromYTime (me, textinterval -> xmin);
 				double xmax = DTW_getXTimeFromYTime (me, textinterval -> xmax);
 				integer ixmin, ixmax;
 				integer numberOfFrames = Matrix_getWindowSamplesX (me, xmin, xmax, & ixmin, & ixmax);
 				double sumOfDistances = 0;
-				while (pathIndex < my pathLength && my path[pathIndex].x < ixmax) {
-					sumOfDistances += my z[my path[pathIndex].y][my path[pathIndex].x];
-					pathIndex++;
+				while (pathIndex < my pathLength && my path [pathIndex].x < ixmax) {
+					sumOfDistances += my z [my path [pathIndex].y] [my path [pathIndex].x];
+					pathIndex ++;
 				}
 				Table_setNumericValue (him.get(), i, 1, textinterval -> xmin);
 				Table_setNumericValue (him.get(), i, 2, textinterval -> xmax);
@@ -152,17 +152,17 @@ autoTable DTW_and_IntervalTier_to_Table (DTW me, IntervalTier thee, double preci
 				Table_setNumericValue (him.get(), i, 4, sumOfDistances / numberOfFrames);
 			}
 		} else if (fabs (my xmin - thy xmin) <= precision && fabs (my xmax - thy xmax) <= precision) {  // map from X to Y
-			long pathIndex = 1;
-			for (long i = 1; i <= numberOfIntervals; i ++) {
+			integer pathIndex = 1;
+			for (integer i = 1; i <= numberOfIntervals; i ++) {
 				TextInterval textinterval = thy intervals.at [i];
 				double ymin = DTW_getYTimeFromXTime (me, textinterval -> xmin);
 				double ymax = DTW_getYTimeFromXTime (me, textinterval -> xmax);
 				integer iymin, iymax;
 				integer numberOfFrames = Matrix_getWindowSamplesY (me, ymin, ymax, & iymin, & iymax);
 				double sumOfDistances = 0;
-				while (pathIndex < my pathLength && my path[pathIndex].y < iymax) {
-					sumOfDistances += my z[my path[pathIndex].y][my path[pathIndex].x];
-					pathIndex++;
+				while (pathIndex < my pathLength && my path [pathIndex].y < iymax) {
+					sumOfDistances += my z [my path [pathIndex].y] [my path [pathIndex].x];
+					pathIndex ++;
 				}
 				Table_setNumericValue (him.get(), i, 1, textinterval -> xmin);
 				Table_setNumericValue (him.get(), i, 2, textinterval -> xmax);
@@ -170,7 +170,7 @@ autoTable DTW_and_IntervalTier_to_Table (DTW me, IntervalTier thee, double preci
 				Table_setNumericValue (him.get(), i, 4, sumOfDistances / numberOfFrames);
 			}
 		} else {
-			Melder_throw (U"The domain of the IntervalTier and one of the domains of the DTW must be equal.");
+			Melder_throw (U"The domain of the IntervalTier and one of the domains of the DTW should be equal.");
 		}
 		return him;
 	} catch (MelderError) {
@@ -179,16 +179,16 @@ autoTable DTW_and_IntervalTier_to_Table (DTW me, IntervalTier thee, double preci
 }
 
 /* Get times from TextGrid and substitute new time form the y-times of the DTW. */
-autoTextTier DTW_and_TextTier_to_TextTier_old (DTW me, TextTier thee) {
+autoTextTier DTW_TextTier_to_TextTier_old (DTW me, TextTier thee) {
 	try {
 		if (my xmin != thy xmin || my xmax != thy xmax) {
-			Melder_throw (U"The domain of the TextTier and the DTW must be equal.");
+			Melder_throw (U"The domain of the TextTier and the DTW should be equal.");
 		}
 		autoTextTier him =  Data_copy (thee);
 		his xmin = my ymin;
 		his xmax = my ymax;
 
-		for (long i = 1; i <= his points.size; i ++) {
+		for (integer i = 1; i <= his points.size; i ++) {
 			TextPoint textpoint = his points.at [i];
 			double time = DTW_getYTimeFromXTime (me, textpoint -> number);
 			textpoint -> number = time;
@@ -199,17 +199,17 @@ autoTextTier DTW_and_TextTier_to_TextTier_old (DTW me, TextTier thee) {
 	}
 }
 
-autoIntervalTier DTW_and_IntervalTier_to_IntervalTier_old (DTW me, IntervalTier thee) {
+autoIntervalTier DTW_IntervalTier_to_IntervalTier_old (DTW me, IntervalTier thee) {
 	try {
 		if ( (my xmin != thy xmin) || my xmax != thy xmax) Melder_throw
-			(U"The domain of the IntervalTier and the DTW must be equal.");
+			(U"The domain of the IntervalTier and the DTW should be equal.");
 
 		autoIntervalTier him = Data_copy (thee);
 
 		his xmin = my ymin;
 		his xmax = my ymax;
 
-		for (long i = 1; i <= his intervals.size; i ++) {
+		for (integer i = 1; i <= his intervals.size; i ++) {
 			TextInterval textinterval = his intervals.at [i];
 			double xmin = DTW_getYTimeFromXTime (me, textinterval -> xmin);
 			textinterval -> xmin = xmin;
@@ -222,26 +222,26 @@ autoIntervalTier DTW_and_IntervalTier_to_IntervalTier_old (DTW me, IntervalTier
 	}
 }
 
-autoTextGrid DTW_and_TextGrid_to_TextGrid_old (DTW me, TextGrid thee) {
+autoTextGrid DTW_TextGrid_to_TextGrid_old (DTW me, TextGrid thee) {
 	try {
 		autoTextGrid him = Thing_new (TextGrid);
 		if (my xmin != thy xmin || my xmax != thy xmax) {
-			Melder_throw (U"The domain of the TextGrid and the y-domain of the DTW must be equal.");
+			Melder_throw (U"The domain of the TextGrid and the y-domain of the DTW should be equal.");
 		}
 
 		his xmin = my ymin;
 		his xmax = my ymax;
 		his tiers = FunctionList_create ();
 
-		for (long i = 1; i <= thy tiers->size; i ++) {
+		for (integer i = 1; i <= thy tiers->size; i ++) {
 			Daata anyTier = thy tiers->at [i];
 
 			if (anyTier -> classInfo == classIntervalTier) {
 
-				autoIntervalTier tier = DTW_and_IntervalTier_to_IntervalTier_old (me, (IntervalTier) anyTier);
+				autoIntervalTier tier = DTW_IntervalTier_to_IntervalTier_old (me, (IntervalTier) anyTier);
 				TextGrid_addTier_copy (him.get(), tier.get());
 			} else if (anyTier -> classInfo == classTextTier) {
-				autoTextTier tier = DTW_and_TextTier_to_TextTier_old (me, (TextTier) anyTier);
+				autoTextTier tier = DTW_TextTier_to_TextTier_old (me, (TextTier) anyTier);
 				TextGrid_addTier_copy (him.get(), tier.get());
 			} else {
 				Melder_throw (U"Unknown tier.");
