@@ -2,7 +2,7 @@
 #define _Minimizers_h_
 /* Minimizers.h
  *
- * Copyright (C) 1993-2017 David Weenink, 2015,2017 Paul Boersma
+ * Copyright (C) 1993-2017 David Weenink, 2015-2018 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,12 +18,6 @@
  * along with this work. If not, see <http://www.gnu.org/licenses/>.
  */
 
-/*
- djmw 20020813 GPL header
- djmw 20030701 Removed non-GPL minimizations
- djmw 20110414 Latest modification.
-*/
-
 #include "Data.h"
 #include "Graphics.h"
 
@@ -31,44 +25,42 @@
 
 Thing_define (Minimizer, Thing) {
 	integer nParameters;	/* the number of parameters */
-	double *p;			/* the parameters */
-	double minimum;		/* current minimum */
-	double *history;	/* previous minima */
-	double tolerance;	/* stop criterium */
-	Daata object;		/* reference to the object that uses this Minimizer */
-	integer funcCalls;		/* the number of times 'func' has been called */
-	integer success;		/* indicates whether I'm done */
-	integer start;			/* start iteration series */
-	integer maxNumOfIterations; /* the current maximum number of iterations */
-	integer iteration;     /* the total number of iterations */
-	void (*afterHook) (Minimizer me, Thing boss); /* to be called after each iteration */
+	double *p;          /* the parameters */
+	double minimum;     /* current minimum */
+	double *history;    /* previous minima */
+	double tolerance;   /* stopping criterion */
+	Daata object;       /* reference to the object that uses this Minimizer */
+	integer funcCalls;  /* the number of times 'func' has been called */
+	bool success;       /* indicates whether I'm done */
+	integer start;      /* start iteration series */
+	integer maxNumOfIterations;   /* the current maximum number of iterations */
+	integer iteration;       /* the total number of iterations */
+	void (*afterHook) (Minimizer me, Thing boss);   /* to be called after each iteration */
 	Thing afterBoss;
-	Graphics gmonitor;		/* graphics to monitor the minimization process */
+	Graphics gmonitor;   /* graphics to monitor the minimization process */
 
 	void v_destroy () noexcept
 		override;
 	void v_info ()
 		override { }
 
-	virtual void v_minimize () { }  /* does the work */
-	virtual void v_reset () { } /* reset the minimizer */
+	virtual void v_minimize () { }   /* does the work */
+	virtual void v_reset () { }
 };
 
 void Minimizer_init (Minimizer me, integer nParameters, Daata object);
 /*
 	Preconditions:
 		nParameters > 0;
-	Postconditions:
-		if (gmonitor) gmonitor != NULL
 */
 
 void Minimizer_reset (Minimizer me, const double guess[]);
 /* reset the start values for the minimizer
  * Preconditions:
- *    guess != NULL;
+ *    !! guess;
  * Post conditions:
  *    p[] = guess[];
- *    my minimum = 1.0e30;
+ *    my minimum = 1e308;
  *    success = maxNumOfIterations = iteration = funcCalls = 0;
  *    reset (me);
  */
@@ -78,7 +70,7 @@ void Minimizer_minimize (Minimizer me, integer maxNumOfIterations, double tolera
  * before minimization and cleared afterwards.
  * Preconditions:
  *    maxNumOfIterations >= 0;
- *    tolerance > 0;
+ *    tolerance > 0.0;
  * Postconditions:
  *    if (reset) Minimizer_reset called with xopt as initial guess.
  *    after each function call: funcCalls++
@@ -96,14 +88,14 @@ double Minimizer_getMinimum (Minimizer me);
 Thing_define (LineMinimizer, Minimizer) {
 	/* the function to be minimized */
 	double (*func) (Daata object, const double p[]);
-	double maxLineStep;	/*maximum step in line search direction */
-	double *direction;	/* search direction vector */
-	double *ptry;		/* point in search direction */
+	double maxLineStep;   // maximum step in line search direction
+	double *direction;    // search direction vector
+	double *ptry;         // point in search direction
 
 	void v_destroy () noexcept
 		override;
 
-	//virtual void v_linmin (double p[], double fp, double direction[], double *fret);	 // David, is dit correct? ja
+	//virtual void v_linmin (double p[], double fp, double direction[], double *fret);
 };
 
 void LineMinimizer_init (LineMinimizer me, integer nParameters, Daata object, double (*func) (Daata object, const double p[]));
@@ -141,16 +133,16 @@ Thing_define (VDSmagtMinimizer, Minimizer) {
 	double lineSearchGradient;
 	integer lineSearchMaxNumOfIterations;
 	double gr0, gropt, df, alplim, alpha, dalpha, alphamin;
-	double *pc;	/* position of current point */
-	double *gc;	/* gradient of current point */
-	double *g0;	/* gradient at beginning of line search */
-	double *s;	/* search direction for line search */
-	double *srst;/* search direction for first iteration after restart */
-	double *grst; /* gradient for first iteration after restart */
+	double *pc;   /* position of current point */
+	double *gc;   /* gradient of current point */
+	double *g0;   /* gradient at beginning of line search */
+	double *s;   /* search direction for line search */
+	double *srst;   /* search direction for first iteration after restart */
+	double *grst;   /* gradient for first iteration after restart */
 	double fc, grc, fch, gr2s, temp, grs, beta, gcg0;
 	double gamma, gamma_in, f0, gsq, gopt_sq;
 	integer lineSearch_iteration, flag, again, one_up, restart;
-	integer restart_flag;
+	bool restart_flag;
 
 	void v_destroy () noexcept
 		override;
