@@ -140,7 +140,7 @@ static bool isTimitPhoneticLabel (const char label[]) {
 static bool isTimitWord (const char label[]) {
 	const char *p = label;
 	for (; *p; p++) {
-		if (isupper (*p) && *p != '\'') {
+		if (Melder_isUpperCaseLetter (*p)) {
 			return false;
 		}
 	}
