@@ -78,7 +78,7 @@ double Cochleagram_difference (Cochleagram me, Cochleagram thee, double tmin, do
 		integer nt = Matrix_getWindowSamplesX (me, tmin, tmax, & itmin, & itmax);
 		if (nt == 0)
 			Melder_throw (U"Window too short.");
-		real80 diff = 0.0;
+		longdouble diff = 0.0;
 		for (integer itime = itmin; itime <= itmax; itime ++) {
 			for (integer ifreq = 1; ifreq <= my ny; ifreq ++) {
 				double d = my z [ifreq] [itime] - thy z [ifreq] [itime];
@@ -86,7 +86,7 @@ double Cochleagram_difference (Cochleagram me, Cochleagram thee, double tmin, do
 			}
 		}
 		diff /= nt * my ny;
-		return sqrt ((real) diff);
+		return sqrt ((double) diff);
 	} catch (MelderError) {
 		Melder_throw (me, U" & ", thee, U": difference not computed.");
 	}
