@@ -62,6 +62,10 @@ void Pitch_Frame_init (Pitch_Frame me, int nCandidates);
 		my intensity == 0.0; // silent
 */
 
+inline static bool Pitch_util_frequencyIsVoiced (double f, double ceiling) {
+	return f > 0.0 && f < ceiling;   // note: return false is f is NaN
+}
+
 bool Pitch_isVoiced_i (Pitch me, integer index);
 /*
 	Is the frame 'index' voiced?
