@@ -164,7 +164,7 @@ double RealTier_getArea (RealTier me, double tmin, double tmax) {
 	 * Sum the areas between the points.
 	 * This works even if imin is 0 (offleft) and/or imax is n + 1 (offright).
 	 */
-	real80 area = 0.0;
+	longdouble area = 0.0;
 	for (integer i = imin; i < imax; i ++) {
 		double tleft, fleft, tright, fright;
 		if (i == imin) {
@@ -183,7 +183,7 @@ double RealTier_getArea (RealTier me, double tmin, double tmax) {
 		}
 		area += 0.5 * (fleft + fright) * (tright - tleft);
 	}
-	return (real) area;
+	return (double) area;
 }
 
 double RealTier_getMean_curve (RealTier me, double tmin, double tmax) {
@@ -208,8 +208,8 @@ double RealTier_getStandardDeviation_curve (RealTier me, double tmin, double tma
 	 * Add the areas between the points.
 	 * This works even if imin is 0 (offleft) and/or imax is n + 1 (offright).
 	 */
-	real mean = RealTier_getMean_curve (me, tmin, tmax);
-	real80 integral = 0.0;
+	double mean = RealTier_getMean_curve (me, tmin, tmax);
+	longdouble integral = 0.0;
 	for (integer i = imin; i < imax; i ++) {
 		double tleft, fleft, tright, fright;
 		if (i == imin) {
@@ -240,38 +240,38 @@ double RealTier_getStandardDeviation_curve (RealTier me, double tmin, double tma
 		double diff = fleft - fright;
 		integral += (sum * sum + (1.0/3.0) * diff * diff) * (tright - tleft);
 	}
-	return sqrt (0.25 * (real) integral / (tmax - tmin));
+	return sqrt (0.25 * (double) integral / (tmax - tmin));
 }
 
-real RealTier_getMean_points (RealTier me, real tmin, real tmax) {
+double RealTier_getMean_points (RealTier me, double tmin, double tmax) {
 	if (tmax <= tmin) { tmin = my xmin; tmax = my xmax; }   // autowindow
 	integer imin, imax;
 	integer n = AnyTier_getWindowPoints (me->asAnyTier(), tmin, tmax, & imin, & imax);
 	if (n == 0) return undefined;
-	real80 sum = 0.0;
+	longdouble sum = 0.0;
 	for (integer i = imin; i <= imax; i ++)
 		sum += my points.at [i] -> value;
-	return (real) sum / n;
+	return (double) sum / n;
 }
 
-real RealTier_getStandardDeviation_points (RealTier me, real tmin, real tmax) {
+double RealTier_getStandardDeviation_points (RealTier me, double tmin, double tmax) {
 	if (tmax <= tmin) { tmin = my xmin; tmax = my xmax; }   // autowindow
 	integer imin, imax;
 	integer n = AnyTier_getWindowPoints (me->asAnyTier(), tmin, tmax, & imin, & imax);
 	if (n < 2) return undefined;
-	real mean = RealTier_getMean_points (me, tmin, tmax);
-	real80 sum = 0.0;
+	double mean = RealTier_getMean_points (me, tmin, tmax);
+	longdouble sum = 0.0;
 	for (integer i = imin; i <= imax; i ++) {
-		real diff = my points.at [i] -> value - mean;
+		double diff = my points.at [i] -> value - mean;
 		sum += diff * diff;
 	}
-	return sqrt ((real) sum / (n - 1));
+	return sqrt ((double) sum / (n - 1));
 }
 
 void RealTier_multiplyPart (RealTier me, double tmin, double tmax, double factor) {
 	for (integer ipoint = 1; ipoint <= my points.size; ipoint ++) {
 		RealPoint point = my points.at [ipoint];
-		real t = point -> number;
+		double t = point -> number;
 		if (t >= tmin && t <= tmax) {
 			point -> value *= factor;
 		}
