@@ -1,6 +1,6 @@
 /* TextGrid.cpp
  *
- * Copyright (C) 1992-2012,2014,2015,2016,2017 Paul Boersma
+ * Copyright (C) 1992-2018 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -471,7 +471,7 @@ integer TextGrid_countIntervalsWhere (TextGrid me, integer tierNumber, kMelder_s
 		IntervalTier tier = TextGrid_checkSpecifiedTierIsIntervalTier (me, tierNumber);
 		for (integer iinterval = 1; iinterval <= tier -> intervals.size; iinterval ++) {
 			TextInterval interval = tier -> intervals.at [iinterval];
-			if (Melder_stringMatchesCriterion (interval -> text, which, criterion)) {
+			if (Melder_stringMatchesCriterion (interval -> text, which, criterion, true)) {
 				count ++;
 			}
 		}
@@ -487,7 +487,7 @@ integer TextGrid_countPointsWhere (TextGrid me, integer tierNumber, kMelder_stri
 		TextTier tier = TextGrid_checkSpecifiedTierIsPointTier (me, tierNumber);
 		for (integer ipoint = 1; ipoint <= tier -> points.size; ipoint ++) {
 			TextPoint point = tier -> points.at [ipoint];
-			if (Melder_stringMatchesCriterion (point -> mark, which, criterion)) {
+			if (Melder_stringMatchesCriterion (point -> mark, which, criterion, true)) {
 				count ++;
 			}
 		}
@@ -696,7 +696,7 @@ autoPointProcess TextGrid_getStartingPoints (TextGrid me, integer tierNumber, kM
 		autoPointProcess thee = PointProcess_create (my xmin, my xmax, 10);
 		for (integer iinterval = 1; iinterval <= tier -> intervals.size; iinterval ++) {
 			TextInterval interval = tier -> intervals.at [iinterval];
-			if (Melder_stringMatchesCriterion (interval -> text, which, criterion)) {
+			if (Melder_stringMatchesCriterion (interval -> text, which, criterion, true)) {
 				PointProcess_addPoint (thee.get(), interval -> xmin);
 			}
 		}
@@ -712,7 +712,7 @@ autoPointProcess TextGrid_getEndPoints (TextGrid me, integer tierNumber, kMelder
 		autoPointProcess thee = PointProcess_create (my xmin, my xmax, 10);
 		for (integer iinterval = 1; iinterval <= tier -> intervals.size; iinterval ++) {
 			TextInterval interval = tier -> intervals.at [iinterval];
-			if (Melder_stringMatchesCriterion (interval -> text, which, criterion)) {
+			if (Melder_stringMatchesCriterion (interval -> text, which, criterion, true)) {
 				PointProcess_addPoint (thee.get(), interval -> xmax);
 			}
 		}
@@ -728,7 +728,7 @@ autoPointProcess TextGrid_getCentrePoints (TextGrid me, integer tierNumber, kMel
 		autoPointProcess thee = PointProcess_create (my xmin, my xmax, 10);
 		for (integer iinterval = 1; iinterval <= tier -> intervals.size; iinterval ++) {
 			TextInterval interval = tier -> intervals.at [iinterval];
-			if (Melder_stringMatchesCriterion (interval -> text, which, criterion)) {
+			if (Melder_stringMatchesCriterion (interval -> text, which, criterion, true)) {
 				PointProcess_addPoint (thee.get(), 0.5 * (interval -> xmin + interval -> xmax));
 			}
 		}
@@ -744,7 +744,7 @@ autoPointProcess TextGrid_getPoints (TextGrid me, integer tierNumber, kMelder_st
 		autoPointProcess thee = PointProcess_create (my xmin, my xmax, 10);
 		for (integer ipoint = 1; ipoint <= tier -> points.size; ipoint ++) {
 			TextPoint point = tier -> points.at [ipoint];
-			if (Melder_stringMatchesCriterion (point -> mark, which, criterion)) {
+			if (Melder_stringMatchesCriterion (point -> mark, which, criterion, true)) {
 				PointProcess_addPoint (thee.get(), point -> number);
 			}
 		}
@@ -763,9 +763,9 @@ autoPointProcess TextGrid_getPoints_preceded (TextGrid me, integer tierNumber,
 		autoPointProcess thee = PointProcess_create (my xmin, my xmax, 10);
 		for (integer ipoint = 1; ipoint <= tier -> points.size; ipoint ++) {
 			TextPoint point = tier -> points.at [ipoint];
-			if (Melder_stringMatchesCriterion (point -> mark, which, criterion)) {
+			if (Melder_stringMatchesCriterion (point -> mark, which, criterion, true)) {
 				TextPoint preceding = ( ipoint <= 1 ? nullptr : tier -> points.at [ipoint - 1] );
-				if (Melder_stringMatchesCriterion (preceding -> mark, precededBy, criterion_precededBy)) {
+				if (Melder_stringMatchesCriterion (preceding -> mark, precededBy, criterion_precededBy, true)) {
 					PointProcess_addPoint (thee.get(), point -> number);
 				}
 			}
@@ -785,9 +785,9 @@ autoPointProcess TextGrid_getPoints_followed (TextGrid me, integer tierNumber,
 		autoPointProcess thee = PointProcess_create (my xmin, my xmax, 10);
 		for (integer ipoint = 1; ipoint <= tier -> points.size; ipoint ++) {
 			TextPoint point = tier -> points.at [ipoint];
-			if (Melder_stringMatchesCriterion (point -> mark, which, criterion)) {
+			if (Melder_stringMatchesCriterion (point -> mark, which, criterion, true)) {
 				TextPoint following = ( ipoint >= tier -> points.size ? nullptr : tier -> points.at [ipoint + 1] );
-				if (Melder_stringMatchesCriterion (following -> mark, followedBy, criterion_followedBy)) {
+				if (Melder_stringMatchesCriterion (following -> mark, followedBy, criterion_followedBy, true)) {
 					PointProcess_addPoint (thee.get(), point -> number);
 				}
 			}
@@ -1236,7 +1236,7 @@ void TextTier_removePoint (TextTier me, integer ipoint) {
 
 void TextTier_removePoints (TextTier me, kMelder_string which, const char32 *criterion) {
 	for (integer i = my points.size; i > 0; i --)
-		if (Melder_stringMatchesCriterion (my points.at [i] -> mark, which, criterion))
+		if (Melder_stringMatchesCriterion (my points.at [i] -> mark, which, criterion, true))
 			my points. removeItem (i);
 }
 
@@ -1725,6 +1725,69 @@ autoTable TextGrid_downto_Table (TextGrid me, bool includeLineNumbers, int timeD
 	return thee;
 }
 
+autoTable TextGrid_tabulateOccurrences (TextGrid me, numvec searchTiers, kMelder_string which, const char32 *criterion, bool caseSensitive) {
+	const int timeDecimals = 6;
+	integer numberOfRows = 0;
+	for (integer itier = 1; itier <= searchTiers.size; itier ++) {
+		integer tierNumber = Melder_iround (searchTiers [itier]);
+		Melder_require (tierNumber > 0 && tierNumber <= my tiers->size, U"Tier number out of range.");
+		Function anyTier = my tiers->at [tierNumber];
+		if (anyTier -> classInfo == classIntervalTier) {
+			IntervalTier tier = static_cast <IntervalTier> (anyTier);
+			for (integer iinterval = 1; iinterval <= tier -> intervals.size; iinterval ++) {
+				TextInterval interval = tier -> intervals.at [iinterval];
+				if (Melder_stringMatchesCriterion (interval -> text, which, criterion, caseSensitive)) {
+					numberOfRows ++;
+				}
+			}
+		} else {
+			TextTier tier = static_cast <TextTier> (anyTier);
+			for (integer ipoint = 1; ipoint <= tier -> points.size; ipoint ++) {
+				TextPoint point = tier -> points.at [ipoint];
+				if (Melder_stringMatchesCriterion (point -> mark, which, criterion, caseSensitive)) {
+					numberOfRows ++;
+				}
+			}
+		}
+	}
+	autoTable thee = Table_createWithColumnNames (numberOfRows, U"time tier text");
+	integer rowNumber = 0;
+	for (integer itier = 1; itier <= searchTiers.size; itier ++) {
+		integer tierNumber = Melder_iround (searchTiers [itier]);
+		Function anyTier = my tiers->at [tierNumber];
+		if (anyTier -> classInfo == classIntervalTier) {
+			IntervalTier tier = static_cast <IntervalTier> (anyTier);
+			for (integer iinterval = 1; iinterval <= tier -> intervals.size; iinterval ++) {
+				TextInterval interval = tier -> intervals.at [iinterval];
+				if (Melder_stringMatchesCriterion (interval -> text, which, criterion, caseSensitive)) {
+					++ rowNumber;
+					Melder_assert (rowNumber <= numberOfRows);
+					double time = 0.5 * (interval -> xmin + interval -> xmax);
+					Table_setStringValue (thee.get(), rowNumber, 1, Melder_fixed (time, timeDecimals));
+					Table_setStringValue (thee.get(), rowNumber, 2, tier -> name);
+					Table_setStringValue (thee.get(), rowNumber, 3, interval -> text);
+				}
+			}
+		} else {
+			TextTier tier = static_cast <TextTier> (anyTier);
+			for (integer ipoint = 1; ipoint <= tier -> points.size; ipoint ++) {
+				TextPoint point = tier -> points.at [ipoint];
+				if (Melder_stringMatchesCriterion (point -> mark, which, criterion, caseSensitive)) {
+					++ rowNumber;
+					Melder_assert (rowNumber <= numberOfRows);
+					double time = point -> number;
+					Table_setStringValue (thee.get(), rowNumber, 1, Melder_fixed (time, timeDecimals));
+					Table_setStringValue (thee.get(), rowNumber, 2, tier -> name);
+					Table_setStringValue (thee.get(), rowNumber, 3, point -> mark);
+				}
+			}
+		}
+	}
+	integer columns [1+1] = { 0, 1 };   // sort by time
+	Table_sortRows_Assert (thee.get(), columns, 1);
+	return thee;
+}
+
 void TextGrid_list (TextGrid me, bool includeLineNumbers, int timeDecimals, bool includeTierNames, bool includeEmptyIntervals) {
 	try {
 		autoTable table = TextGrid_downto_Table (me, includeLineNumbers, timeDecimals, includeTierNames, includeEmptyIntervals);
