@@ -26,11 +26,11 @@ double structVector :: v_getVector (integer irow, integer icol) {
 	if (ny == 1) return z [1] [icol];   // optimization
 	if (irow == 0) {
 		if (ny == 2) return 0.5 * (z [1] [icol] + z [2] [icol]);   // optimization
-		real80 sum = 0.0;
+		longdouble sum = 0.0;
 		for (integer channel = 1; channel <= ny; channel ++) {
 			sum += z [channel] [icol];
 		}
-		return real (sum / ny);
+		return double (sum / ny);
 	}
 	Melder_assert (irow > 0 && irow <= ny);
 	return z [irow] [icol];
@@ -52,11 +52,11 @@ double structVector :: v_getFunction1 (integer irow, double x) {
 		if (ny == 2) {
 			z1 = 0.5 * (z [1] [icol] + z [2] [icol]);   // optimization
 		} else {
-			real80 sum = 0.0;
+			longdouble sum = 0.0;
 			for (integer channel = 1; channel <= ny; channel ++) {
 				sum += z [channel] [icol];
 			}
-			z1 = real (sum / ny);
+			z1 = double (sum / ny);
 		}
 	} else {
 		Melder_assert (irow > 0 && irow <= ny);
@@ -71,11 +71,11 @@ double structVector :: v_getFunction1 (integer irow, double x) {
 		if (ny == 2) {
 			z2 = 0.5 * (z [1] [icol + 1] + z [2] [icol + 1]);   // optimization
 		} else {
-			real80 sum = 0.0;
+			longdouble sum = 0.0;
 			for (integer channel = 1; channel <= ny; channel ++) {
 				sum += z [channel] [icol + 1];
 			}
-			z2 = real (sum / ny);
+			z2 = double (sum / ny);
 		}
 	} else {
 		Melder_assert (irow > 0 && irow <= ny);
@@ -96,11 +96,11 @@ double structVector :: v_getValueAtSample (integer isamp, integer ilevel, int un
 	} else if (ny == 2) {
 		value = 0.5 * (z [1] [isamp] + z [2] [isamp]);   // optimization
 	} else {
-		real80 sum = 0.0;
+		longdouble sum = 0.0;
 		for (integer channel = 1; channel <= ny; channel ++) {
 			sum += z [channel] [isamp];
 		}
-		value = real (sum / ny);
+		value = double (sum / ny);
 	}
 	return isdefined (value) ? v_convertStandardToSpecialUnit (value, ilevel, unit) : undefined;
 }
@@ -301,7 +301,7 @@ double Vector_getStandardDeviation (Vector me, double xmin, double xmax, integer
 	integer imin, imax, n = Sampled_getWindowSamples (me, xmin, xmax, & imin, & imax);
 	if (n < 2) return undefined;
 	if (ilevel == Vector_CHANNEL_AVERAGE) {
-		real80 sum2 = 0.0;
+		longdouble sum2 = 0.0;
 		for (integer channel = 1; channel <= my ny; channel ++) {
 			double mean = Vector_getMean (me, xmin, xmax, channel);
 			for (integer i = imin; i <= imax; i ++) {
@@ -309,17 +309,17 @@ double Vector_getStandardDeviation (Vector me, double xmin, double xmax, integer
 				sum2 += diff * diff;
 			}
 		}
-		return sqrt (real (sum2 / (n * my ny - my ny)));   // The number of constraints equals the number of channels,
+		return sqrt (double (sum2 / (n * my ny - my ny)));   // The number of constraints equals the number of channels,
 				// because from every channel its own mean was subtracted.
 				// Corollary: a two-channel mono sound will have the same stdev as the corresponding one-channel sound.
 	}
 	double mean = Vector_getMean (me, xmin, xmax, ilevel);
-	real80 sum2 = 0.0;
+	longdouble sum2 = 0.0;
 	for (integer i = imin; i <= imax; i ++) {
 		double diff = my z [ilevel] [i] - mean;
 		sum2 += diff * diff;
 	}
-	return sqrt (real (sum2 / (n - 1)));
+	return sqrt (double (sum2 / (n - 1)));
 }
 
 /***** Modify. *****/
