@@ -1,6 +1,6 @@
 /* TableOfReal.cpp
  *
- * Copyright (C) 1992-2012,2014,2015,2016,2017 Paul Boersma
+ * Copyright (C) 1992-2018 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -152,22 +152,22 @@ integer TableOfReal_columnLabelToIndex (TableOfReal me, const char32 *label) {
 double TableOfReal_getColumnMean (TableOfReal me, integer columnNumber) {
 	if (columnNumber < 1 || columnNumber > my numberOfColumns) return undefined;
 	if (my numberOfRows < 1) return undefined;
-	real80 sum = 0.0;
+	longdouble sum = 0.0;
 	for (integer irow = 1; irow <= my numberOfRows; irow ++)
 		sum += my data [irow] [columnNumber];
-	return (real) sum / my numberOfRows;
+	return (double) sum / my numberOfRows;
 }
 
 double TableOfReal_getColumnStdev (TableOfReal me, integer columnNumber) {
 	if (columnNumber < 1 || columnNumber > my numberOfColumns) return undefined;
 	if (my numberOfRows < 2) return undefined;
 	double mean = TableOfReal_getColumnMean (me, columnNumber);
-	real80 sum = 0.0;
+	longdouble sum = 0.0;
 	for (integer irow = 1; irow <= my numberOfRows; irow ++) {
-		real d = my data [irow] [columnNumber] - mean;
+		double d = my data [irow] [columnNumber] - mean;
 		sum += d * d;
 	}
-	return sqrt ((real) sum / (my numberOfRows - 1));
+	return sqrt ((double) sum / (my numberOfRows - 1));
 }
 
 /***** MODIFY *****/
@@ -389,7 +389,7 @@ autoTableOfReal TableOfReal_extractRowsWhereLabel (TableOfReal me, kMelder_strin
 	try {
 		integer n = 0;
 		for (integer irow = 1; irow <= my numberOfRows; irow ++) {
-			if (Melder_stringMatchesCriterion (my rowLabels [irow], which, criterion)) {
+			if (Melder_stringMatchesCriterion (my rowLabels [irow], which, criterion, true)) {
 				n ++;
 			}
 		}
@@ -399,7 +399,7 @@ autoTableOfReal TableOfReal_extractRowsWhereLabel (TableOfReal me, kMelder_strin
 		copyColumnLabels (me, thee.get());
 		n = 0;
 		for (integer irow = 1; irow <= my numberOfRows; irow ++)
-			if (Melder_stringMatchesCriterion (my rowLabels [irow], which, criterion))
+			if (Melder_stringMatchesCriterion (my rowLabels [irow], which, criterion, true))
 				copyRow (me, irow, thee.get(), ++ n);
 		return thee;
 	} catch (MelderError) {
@@ -435,7 +435,7 @@ autoTableOfReal TableOfReal_extractColumnsWhereLabel (TableOfReal me, kMelder_st
 	try {
 		integer n = 0;
 		for (integer icol = 1; icol <= my numberOfColumns; icol ++) {
-			if (Melder_stringMatchesCriterion (my columnLabels [icol], which, criterion)) {
+			if (Melder_stringMatchesCriterion (my columnLabels [icol], which, criterion, true)) {
 				n ++;
 			}
 		}
@@ -445,7 +445,7 @@ autoTableOfReal TableOfReal_extractColumnsWhereLabel (TableOfReal me, kMelder_st
 		copyRowLabels (me, thee.get());
 		n = 0;
 		for (integer icol = 1; icol <= my numberOfColumns; icol ++) {
-			if (Melder_stringMatchesCriterion (my columnLabels [icol], which, criterion)) {
+			if (Melder_stringMatchesCriterion (my columnLabels [icol], which, criterion, true)) {
 				copyColumn (me, icol, thee.get(), ++ n);
 			}
 		}
@@ -470,7 +470,7 @@ static integer *getElementsOfRanges (const char32 *ranges, integer maximumElemen
 	for (;;) {
 		while (*p == U' ' || *p == U'\t') p ++;
 		if (*p == U'\0') break;
-		if (isdigit ((int) *p)) {
+		if (Melder_isAsciiDecimalNumber (*p)) {
 			integer currentElement = Melder_atoi (p);
 			if (currentElement == 0)
 				Melder_throw (U"No such ", elementType, U": 0 (minimum is 1).");
@@ -478,15 +478,14 @@ static integer *getElementsOfRanges (const char32 *ranges, integer maximumElemen
 				Melder_throw (U"No such ", elementType, U": ", currentElement, U" (maximum is ", maximumElement, U").");
 			*numberOfElements += 1;
 			previousElement = currentElement;
-			do { p ++; } while (isdigit ((int) *p));
+			do { p ++; } while (Melder_isAsciiDecimalNumber (*p));
 		} else if (*p == ':') {
 			if (previousElement == 0)
 				Melder_throw (U"Cannot start range with colon.");
 			do { p ++; } while (*p == U' ' || *p == U'\t');
 			if (*p == U'\0')
 				Melder_throw (U"Cannot end range with colon.");
-			if (! isdigit ((int) *p))
-				Melder_throw (U"End of range should be a positive whole number.");
+			Melder_require (Melder_isAsciiDecimalNumber (*p), U"End of range should be a positive whole number.");
 			integer currentElement = Melder_atoi (p);
 			if (currentElement == 0)
 				Melder_throw (U"No such ", elementType, U": 0 (minimum is 1).");
@@ -498,7 +497,7 @@ static integer *getElementsOfRanges (const char32 *ranges, integer maximumElemen
 				*numberOfElements += previousElement - currentElement;
 			}
 			previousElement = currentElement;
-			do { p ++; } while (isdigit ((int) *p));
+			do { p ++; } while (Melder_isAsciiDecimalNumber (*p));
 		} else {
 			Melder_throw (U"Start of range should be a positive whole number.");
 		}
@@ -516,11 +515,11 @@ static integer *getElementsOfRanges (const char32 *ranges, integer maximumElemen
 	for (;;) {
 		while (*p == U' ' || *p == U'\t') p ++;
 		if (*p == U'\0') break;
-		if (isdigit ((int) *p)) {
+		if (Melder_isAsciiDecimalNumber (*p)) {
 			integer currentElement = Melder_atoi (p);
 			elements [++ *numberOfElements] = currentElement;
 			previousElement = currentElement;
-			do { p ++; } while (isdigit ((int) *p));
+			do { p ++; } while (Melder_isAsciiDecimalNumber (*p));
 		} else if (*p == ':') {
 			do { p ++; } while (*p == U' ' || *p == U'\t');
 			integer currentElement = Melder_atoi (p);
@@ -534,7 +533,7 @@ static integer *getElementsOfRanges (const char32 *ranges, integer maximumElemen
 				}
 			}
 			previousElement = currentElement;
-			do { p ++; } while (isdigit ((int) *p));
+			do { p ++; } while (Melder_isAsciiDecimalNumber (*p));
 		}
 	}
 	return elements.transfer();
