@@ -2,7 +2,7 @@
 #define _Ui_h_
 /* Ui.h
  *
- * Copyright (C) 1992-2011,2012,2013,2015,2017 Paul Boersma
+ * Copyright (C) 1992-2011,2012,2013,2015,2017,2018 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -80,8 +80,30 @@ Thing_define (UiOption, Thing) {
 	GuiObject menuItem;
 };
 
+enum class _kUiField_type {
+	REAL_ = 1,
+	REAL_OR_UNDEFINED_ = 2,
+	POSITIVE_ = 3,
+	INTEGER_ = 4,
+	NATURAL_ = 5,
+	WORD_ = 6,
+	SENTENCE_ = 7,
+	COLOUR_ = 8,
+	CHANNEL_ = 9,
+	LABEL_ = 10,
+	TEXT_ = 11,
+	NUMVEC_ = 12,
+	NUMMAT_ = 13,
+	BOOLEAN_ = 14,
+	RADIO_ = 15,
+	OPTIONMENU_ = 16,
+	LIST_ = 17,
+	LABELLED_TEXT_MIN_ = 1,
+	LABELLED_TEXT_MAX_ = 9
+};
+
 Thing_define (UiField, Thing) {
-	int type;
+	_kUiField_type type;
 	const char32 *formLabel;
 	double realValue;
 	integer integerValue, integerDefaultValue;
@@ -89,7 +111,6 @@ Thing_define (UiField, Thing) {
 	autonumvec numericVectorValue;
 	autonummat numericMatrixValue;
 	Graphics_Colour colourValue;
-	char *stringValueA;
 	OrderedOf<structUiOption> options;
 	integer numberOfStrings;
 	const char32 **strings;
@@ -120,7 +141,7 @@ Thing_define (UiField, Thing) {
 };
 
 #define UiCallback_ARGS \
-	UiForm sendingForm, int narg, Stackel args, const char32 *sendingString, Interpreter interpreter, const char32 *invokingButtonTitle, bool modified, void *closure
+	UiForm _sendingForm, integer _narg, Stackel _args, const char32 *_sendingString, Interpreter interpreter, const char32 *_invokingButtonTitle, bool _modified, void *_closure
 typedef void (*UiCallback) (UiCallback_ARGS);
 
 #define MAXIMUM_NUMBER_OF_FIELDS  50
@@ -134,14 +155,14 @@ Thing_define (UiForm, Thing) {
 	void *buttonClosure;
 
 	/*
-	 * In case the validity of the form depends on the selected objects.
-	 */
+		In case the validity of the form depends on the selected objects.
+	*/
 	bool (*allowExecutionHook) (void *closure);
 	void *allowExecutionClosure;
 
 	/*
-	 * In case the form is built by specifying buttons (rather than a system-built-in file dialog).
-	 */
+		In case the form is built by specifying buttons (rather than a system-built-in file dialog).
+	*/
 	GuiDialog d_dialogForm;
 	void (*applyCallback) (UiForm dia, void *closure);
 	void (*cancelCallback) (UiForm dia, void *closure);
@@ -153,8 +174,8 @@ Thing_define (UiForm, Thing) {
 	bool destroyWhenUnmanaged, isPauseForm;
 
 	/*
-	 * In case the form contains a file.
-	 */
+		In case the form contains a file.
+	*/
 	structMelderFile file;
 	int shiftKeyPressed;
 	bool allowMultipleFiles;   // for input
@@ -175,7 +196,7 @@ UiField UiForm_addNatural (UiForm me, integer *variable, const char32 *variableN
 UiField UiForm_addWord (UiForm me, char32 **variable, const char32 *variableName, const char32 *label, const char32 *defaultValue);
 UiField UiForm_addSentence (UiForm me, char32 **variable, const char32 *variableName, const char32 *label, const char32 *defaultValue);
 UiField UiForm_addLabel (UiForm me, char32 **variable, const char32 *label);
-UiField UiForm_addBoolean (UiForm me, bool *variable, const char32 *variableName, const char32 *label, int defaultValue);
+UiField UiForm_addBoolean (UiForm me, bool *variable, const char32 *variableName, const char32 *label, bool defaultValue);
 UiField UiForm_addText (UiForm me, char32 **variable, const char32 *variableName, const char32 *name, const char32 *defaultValue);
 UiField UiForm_addNumvec (UiForm me, numvec *variable, const char32 *variableName, const char32 *name, const char32 *defaultValue);
 UiField UiForm_addNummat (UiForm me, nummat *variable, const char32 *variableName, const char32 *name, const char32 *defaultValue);
@@ -246,7 +267,7 @@ void UiForm_do (UiForm me, bool modified);
 		The form will still appear on the screen,
 		but the `okCallback` will be called immediately.
 */
-void UiForm_info (UiForm me, int narg);
+void UiForm_info (UiForm me, integer narg);
 
 /*
 	The `okCallback` can use the following seven functions to ask arguments.
@@ -263,7 +284,7 @@ integer UiForm_getInteger_check (UiForm me, const char32 *fieldName);
 char32 * UiForm_getString_check (UiForm me, const char32 *fieldName);
 Graphics_Colour UiForm_getColour_check (UiForm me, const char32 *fieldName);
 
-void UiForm_call (UiForm me, int narg, Stackel args, Interpreter interpreter);
+void UiForm_call (UiForm me, integer narg, Stackel args, Interpreter interpreter);
 void UiForm_parseString (UiForm me, const char32 *arguments, Interpreter interpreter);
 
 UiForm UiInfile_create (GuiWindow parent, const char32 *title,
