@@ -1,6 +1,6 @@
 /* praat.cpp
  *
- * Copyright (C) 1992-2012,2013,2014,2015,2016,2017 Paul Boersma
+ * Copyright (C) 1992-2018 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -109,8 +109,8 @@ static GuiList praatList_objects;
 
 /***** selection *****/
 
-integer praat_idOfSelected (ClassInfo klas, int inplace) {
-	int place = inplace, IOBJECT;
+integer praat_idOfSelected (ClassInfo klas, integer inplace) {
+	integer place = inplace, IOBJECT;
 	if (place == 0) place = 1;
 	if (place > 0) {
 		WHERE (SELECTED && (! klas || CLASS == klas)) {
@@ -131,8 +131,17 @@ integer praat_idOfSelected (ClassInfo klas, int inplace) {
 	return 0;
 }
 
-char32 * praat_nameOfSelected (ClassInfo klas, int inplace) {
-	int place = inplace, IOBJECT;
+autonumvec praat_idsOfAllSelected (ClassInfo klas) {
+	autonumvec result (praat_numberOfSelected (klas), kTensorInitializationType::RAW);
+	integer selectedObjectNumber = 0, IOBJECT;
+	WHERE (SELECTED && (! klas || CLASS == klas)) {
+		result.at [++ selectedObjectNumber] = ID;
+	}
+	return result;
+}
+
+char32 * praat_nameOfSelected (ClassInfo klas, integer inplace) {
+	integer place = inplace, IOBJECT;
 	if (place == 0) place = 1;
 	if (place > 0) {
 		WHERE (SELECTED && (! klas || CLASS == klas)) {
@@ -153,7 +162,7 @@ char32 * praat_nameOfSelected (ClassInfo klas, int inplace) {
 	return 0;   // failure
 }
 
-int praat_numberOfSelected (ClassInfo klas) {
+integer praat_numberOfSelected (ClassInfo klas) {
 	if (! klas) return theCurrentPraatObjects -> totalSelection;
 	integer readableClassId = klas -> sequentialUniqueIdOfReadableClass;
 	if (readableClassId == 0) Melder_fatal (U"No sequential unique ID for class ", klas -> className, U".");
@@ -550,8 +559,10 @@ static void praat_exit (int exit_code) {
 				MelderString_append (& buffer, U"# This file is generated automatically when you quit the ", praatP.title, U" program.\n");
 				MelderString_append (& buffer, U"# It contains the buttons that you added interactively to the fixed or dynamic menus,\n");
 				MelderString_append (& buffer, U"# and the buttons that you hid or showed.\n\n");
-				praat_saveMenuCommands (& buffer);
+				praat_saveAddedMenuCommands (& buffer);
+				praat_saveToggledMenuCommands (& buffer);
 				praat_saveAddedActions (& buffer);
+				praat_saveToggledActions (& buffer);
 				MelderFile_writeText (& buttonsFile, buffer.string, kMelder_textOutputEncoding::ASCII_THEN_UTF16);
 			} catch (MelderError) {
 				Melder_clearError ();
@@ -1170,7 +1181,7 @@ void praat_init (const char32 *title, int argc, char **argv)
 	/*
 	 * Construct a main-window title like "MyProg 3.2".
 	 */
-	programName [0] = (char32) tolower ((int) programName [0]);
+	programName [0] = Melder_toLowerCase (programName [0]);
 
 	/*
 	 * Get home directory, e.g. "/home/miep/", or "/Users/miep/", or just "/".
@@ -1533,49 +1544,52 @@ void praat_run () {
 		Check the locale, to ensure identical behaviour on all computers.
 	*/
 	Melder_assert (str32equ (Melder_double (1.5), U"1.5"));   // check locale settings; because of the required file portability Praat cannot stand "1,5"
-	Melder_assert (Melder_isWhiteSpace (' '));
-	Melder_assert (Melder_isWhiteSpace ('\r'));
-	Melder_assert (Melder_isWhiteSpace ('\n'));
-	Melder_assert (Melder_isWhiteSpace ('\t'));
-	Melder_assert (Melder_isWhiteSpace ('\f'));
-	Melder_assert (Melder_isWhiteSpace ('\v'));
-	Melder_assert (Melder_isWhiteSpace (UNICODE_OGHAM_SPACE_MARK));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_MONGOLIAN_VOWEL_SEPARATOR));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_EN_QUAD));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_EM_QUAD));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_EN_SPACE));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_EM_SPACE));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_THREE_PER_EM_SPACE));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_FOUR_PER_EM_SPACE));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_SIX_PER_EM_SPACE));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_FIGURE_SPACE));   // questionable
-	Melder_assert (Melder_isWhiteSpace (UNICODE_PUNCTUATION_SPACE));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_THIN_SPACE));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_HAIR_SPACE));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_ZERO_WIDTH_SPACE));   // questionable
-	//Melder_assert (iswspace (UNICODE_ZERO_WIDTH_NON_JOINER));
-	//Melder_assert (iswspace (UNICODE_ZERO_WIDTH_JOINER));
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (' '));
+	Melder_assert (Melder_isHorizontalOrVerticalSpace ('\r'));
+	Melder_assert (Melder_isHorizontalOrVerticalSpace ('\n'));
+	Melder_assert (Melder_isHorizontalOrVerticalSpace ('\t'));
+	Melder_assert (Melder_isHorizontalOrVerticalSpace ('\f'));
+	Melder_assert (Melder_isHorizontalOrVerticalSpace ('\v'));
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_NO_BREAK_SPACE));
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_OGHAM_SPACE_MARK));   // ISO 30112
+	//Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_MONGOLIAN_VOWEL_SEPARATOR));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_EN_QUAD));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_EM_QUAD));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_EN_SPACE));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_EM_SPACE));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_THREE_PER_EM_SPACE));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_FOUR_PER_EM_SPACE));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_SIX_PER_EM_SPACE));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_FIGURE_SPACE));   // questionable
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_PUNCTUATION_SPACE));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_THIN_SPACE));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_HAIR_SPACE));   // ISO 30112
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_ZERO_WIDTH_SPACE));   // questionable
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_ZERO_WIDTH_NON_JOINER));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_ZERO_WIDTH_JOINER));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_ZERO_WIDTH_NO_BREAK_SPACE));   // this is the byte-order mark!
 	//Melder_assert (iswspace (UNICODE_LEFT_TO_RIGHT_MARK));
 	//Melder_assert (iswspace (UNICODE_RIGHT_TO_LEFT_MARK));
-	Melder_assert (Melder_isWhiteSpace (UNICODE_LINE_SEPARATOR));   // ISO 30112
-	Melder_assert (Melder_isWhiteSpace (UNICODE_PARAGRAPH_SEPARATOR));   // ISO 30112
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_LEFT_TO_RIGHT_EMBEDDING));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_RIGHT_TO_LEFT_EMBEDDING));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_POP_DIRECTIONAL_FORMATTING));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_LEFT_TO_RIGHT_OVERRIDE));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_RIGHT_TO_LEFT_OVERRIDE));
-	Melder_assert (Melder_isWhiteSpace (UNICODE_MEDIUM_MATHEMATICAL_SPACE));   // ISO 30112
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_WORD_JOINER));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_FUNCTION_APPLICATION));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_INVISIBLE_TIMES));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_INVISIBLE_SEPARATOR));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_INHIBIT_SYMMETRIC_SWAPPING));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_ACTIVATE_SYMMETRIC_SWAPPING));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_INHIBIT_ARABIC_FORM_SHAPING));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_ACTIVATE_ARABIC_FORM_SHAPING));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_NATIONAL_DIGIT_SHAPES));
-	Melder_assert (! Melder_isWhiteSpace (UNICODE_NOMINAL_DIGIT_SHAPES));
-	Melder_assert (Melder_isWhiteSpace (UNICODE_IDEOGRAPHIC_SPACE));   // ISO 30112; occurs on Japanese computers
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_LINE_SEPARATOR));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_PARAGRAPH_SEPARATOR));   // ISO 30112
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_NARROW_NO_BREAK_SPACE));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_LEFT_TO_RIGHT_EMBEDDING));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_RIGHT_TO_LEFT_EMBEDDING));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_POP_DIRECTIONAL_FORMATTING));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_LEFT_TO_RIGHT_OVERRIDE));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_RIGHT_TO_LEFT_OVERRIDE));
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_MEDIUM_MATHEMATICAL_SPACE));   // ISO 30112
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_WORD_JOINER));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_FUNCTION_APPLICATION));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_INVISIBLE_TIMES));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_INVISIBLE_SEPARATOR));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_INHIBIT_SYMMETRIC_SWAPPING));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_ACTIVATE_SYMMETRIC_SWAPPING));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_INHIBIT_ARABIC_FORM_SHAPING));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_ACTIVATE_ARABIC_FORM_SHAPING));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_NATIONAL_DIGIT_SHAPES));
+	Melder_assert (! Melder_isHorizontalOrVerticalSpace (UNICODE_NOMINAL_DIGIT_SHAPES));
+	Melder_assert (Melder_isHorizontalOrVerticalSpace (UNICODE_IDEOGRAPHIC_SPACE));   // ISO 30112; occurs on Japanese computers
 
 	{ unsigned char dummy = 200;
 		Melder_assert ((int) dummy == 200);
@@ -1639,7 +1653,7 @@ void praat_run () {
 	}
 	Melder_assert (isdefined (0.0));
 	Melder_assert (isdefined (1e300));
-	Melder_assert (isundef ((real) 1e320L));
+	Melder_assert (isundef ((double) 1e320L));
 	Melder_assert (isundef (pow (10.0, 330)));
 	Melder_assert (isundef (0.0 / 0.0));
 	Melder_assert (isundef (1.0 / 0.0));
@@ -1679,9 +1693,9 @@ void praat_run () {
 		autonumvec b { x };
 		//autonumvec c = x;   // implicit construction not OK
 	}
-	Melder_assert (sizeof (real32) == 4);
-	Melder_assert (sizeof (real64) == 8);
-	Melder_assert (sizeof (real80) >= 12);
+	Melder_assert (sizeof (float) == 4);
+	Melder_assert (sizeof (double) == 8);
+	Melder_assert (sizeof (longdouble) >= 8);   // this can be 8, 12 or 16
 	Melder_assert (sizeof (integer) == sizeof (void *));
 	if (sizeof (off_t) < 8)
 		Melder_fatal (U"sizeof(off_t) is less than 8. Compile Praat with -D_FILE_OFFSET_BITS=64.");
