@@ -1,6 +1,6 @@
 /* praat_script.cpp
  *
- * Copyright (C) 1993-2012,2013,2014,2015,2016,2017 Paul Boersma
+ * Copyright (C) 1993-2018 Paul Boersma
  * 
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -186,12 +186,12 @@ int praat_executeCommand (Interpreter interpreter, char32 *command) {
 	//trace (U"praat_executeCommand: ", Melder_pointer (interpreter), U": ", command);
 	if (command [0] == U'\0' || command [0] == U'#' || command [0] == U'!' || command [0] == U';')
 		/* Skip empty lines and comments. */;
-	else if ((command [0] == U'.' || command [0] == U'+' || command [0] == U'-') && isupper ((int) command [1])) {   // selection?
+	else if ((command [0] == U'.' || command [0] == U'+' || command [0] == U'-') && Melder_isAsciiUpperCaseLetter (command [1])) {   // selection?
 		int IOBJECT = praat_findObjectFromString (interpreter, command + 1);
 		if (command [0] == '.') praat_deselectAll ();
 		if (command [0] == '-') praat_deselect (IOBJECT); else praat_select (IOBJECT); 
 		praat_show ();
-	} else if (islower ((int) command [0])) {   // all directives start with a lower-case letter
+	} else if (Melder_isAsciiLowerCaseLetter (command [0])) {   // all directives start with an ASCII lower-case letter
 		if (str32nequ (command, U"select ", 7)) {
 			if (str32nequ (command + 7, U"all", 3) && (command [10] == U'\0' || command [10] == U' ' || command [10] == U'\t')) {
 				praat_selectAll ();
@@ -296,7 +296,7 @@ int praat_executeCommand (Interpreter interpreter, char32 *command) {
 		} else if (str32nequ (command, U"editor", 6)) {
 			if (theCurrentPraatObjects != & theForegroundPraatObjects)
 				Melder_throw (U"The script command \"editor\" is not available inside manuals.");
-			if (command [6] == U' ' && isalpha ((int) command [7])) {
+			if (command [6] == U' ' && Melder_isLetter (command [7])) {
 				praatP. editor = praat_findEditorFromString (command + 7);
 			} else if (command [6] == U'\0') {
 				if (interpreter && interpreter -> editorClass) {
@@ -437,7 +437,7 @@ int praat_executeCommand (Interpreter interpreter, char32 *command) {
 		/* See if command exists and is available; ignore separators. */
 		/* First try loose commands, then fixed commands. */
 
-		int narg;
+		integer narg;
 		char32 command2 [200];
 		if (hasColon) {
 			narg = parseCommaSeparatedArguments (interpreter, arguments, args);
@@ -555,7 +555,7 @@ void praat_executeScriptFromFile (MelderFile file, const char32 *arguments) {
 	}
 }
 
-void praat_executeScriptFromFileName (const char32 *fileName, int narg, Stackel args) {
+void praat_executeScriptFromFileName (const char32 *fileName, integer narg, Stackel args) {
 	/*
 	 * The argument 'fileName' is unsafe. Duplicate its contents.
 	 */
@@ -636,7 +636,7 @@ void praat_executeScriptFromDialog (UiForm dia) {
 	Interpreter_run (interpreter.get(), text.peek());
 }
 
-static void secondPassThroughScript (UiForm sendingForm, int /* narg */, Stackel /* args */,
+static void secondPassThroughScript (UiForm sendingForm, integer /* narg */, Stackel /* args */,
 	const char32 * /* sendingString_dummy */, Interpreter /* interpreter_dummy */,
 	const char32 * /* invokingButtonTitle */, bool /* modified */, void *)
 {
@@ -666,14 +666,14 @@ static void firstPassThroughScript (MelderFile file) {
 	}
 }
 
-static void fileSelectorOkCallback (UiForm dia, int /* narg */, Stackel /* args */,
+static void fileSelectorOkCallback (UiForm dia, integer /* narg */, Stackel /* args */,
 	const char32 * /* sendingString_dummy */, Interpreter /* interpreter_dummy */,
 	const char32 * /* invokingButtonTitle */, bool /* modified */, void *)
 {
 	firstPassThroughScript (UiFile_getFile (dia));
 }
 
-void DO_RunTheScriptFromAnyAddedMenuCommand (UiForm /* sendingForm_dummy */, int /* narg */, Stackel /* args */,
+void DO_RunTheScriptFromAnyAddedMenuCommand (UiForm /* sendingForm_dummy */, integer /* narg */, Stackel /* args */,
 	const char32 *scriptPath, Interpreter /* interpreter */,
 	const char32 * /* invokingButtonTitle */, bool /* modified */, void *)
 {
