@@ -1,6 +1,6 @@
 /* praat_statistics.cpp
  *
- * Copyright (C) 1992-2012,2014,2015,2016,2017 Paul Boersma
+ * Copyright (C) 1992-2012,2014-2018 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 
 #include <time.h>
 #include <locale.h>
+#include <thread>
 #include "praatP.h"
 
 static struct {
@@ -114,6 +115,7 @@ void praat_reportSystemProperties () {
 	#ifdef linux
 		MelderInfo_writeLine (U"linux is \"" xstr (linux) "\".");
 	#endif
+	MelderInfo_writeLine (U"The number of processors is ", std::thread::hardware_concurrency(), U".");
 	MelderInfo_close ();
 }
 
